
.. _io/edgelist:

Edgelist
********

These methods provide the importers' functionality without actually constructing a graph. 
They simply return an in-memory edge list. This is helpful for example in order to bulk 
load a sparse graph, or to perform some preprocessing before loading a graph.

.. automodule:: jgrapht.io.edgelist
   :members:

